Enum Fd

pub enum Fd {
    None(&'static Location<'static>),
    Owned(OwnedFd),
    Borrowed(RawFd),
}

Variants



None(&'static Location<'static>)



Owned(OwnedFd)



Borrowed(RawFd)

Implementations

Source

impl Fd

pub unsafe fn from_raw_fd(fd: RawFd) -> Self

Safety

The resource pointed to by fd must be open and suitable for assuming ownership. The resource must not require any cleanup other than close.

pub unsafe fn share_raw_fd(fd: RawFd) -> Self

Safety

Given fd must not be closed as long as the created Fd is alive.

pub fn close(&mut self)

pub fn try_as_raw_fd(&self) -> Result<RawFd>

pub fn is_readable(&self) -> Result<bool>

pub fn is_writeable(&self) -> Result<bool>

pub unsafe fn ioctl_ptr<T>(&self, request: c_ulong, p: *mut T) -> Result<i32>

Safety

require p to match the request

pub unsafe fn ioctl_ptrc<T>(&self, request: c_ulong, p: *const T) -> Result<i32>

Safety

require p to match the request

pub unsafe fn mmap( &self, addr: *mut c_void, len: size_t, prot: c_int, flags: c_int, offset: off_t, ) -> Result<*mut c_void>

Safety

allocated memory must be released manually